@@ -54,7 +54,7 @@
 ** do file write for each update.  Instead we'll do it at every
 ** OVBUFF_SYNC_COUNT updates.
 */
-#define OVBUFF_SYNC_COUNT   (innconf->icdsynccount * 10 + 1)
+#define OVBUFF_SYNC_COUNT   (innconf->ovflushcount)
 
 /* ovbuff header */
 #define OVBUFFMASIZ         8
@@ -343,7 +343,7 @@ ovparse_part_line(char *l)
     ovbuff->index = strtoul(l, NULL, 10);
     for (; tmp != (OVBUFF *) NULL; tmp = tmp->next) {
         if (tmp->index == ovbuff->index) {
-            warn("buffindexed: dupulicate index in line '%s'", l);
+            warn("buffindexed: duplicate index in line '%s'", l);
             free(ovbuff);
             return false;
         }
@@ -361,7 +361,7 @@ ovparse_part_line(char *l)
     memset(ovbuff->path, '\0', OVBUFFPASIZ);
     strlcpy(ovbuff->path, l, OVBUFFPASIZ);
     if (stat(ovbuff->path, &sb) < 0) {
-        warn("buffindexed: file '%s' does not exist, ignoring '%d'",
+        warn("buffindexed: file '%s' does not exist, ignoring '%u'",
              ovbuff->path, ovbuff->index);
         free(ovbuff);
         return false;
@@ -373,8 +373,7 @@ ovparse_part_line(char *l)
     /*
     ** The minimum article offset will be the size of the bitfield itself,
     ** len / (blocksize * 8), plus however many additional blocks the
-    *OVBUFFHEAD
-    ** external header occupies ... then round up to the next block.
+    ** *OVBUFFHEAD external header occupies... then round up to the next block.
     */
     base = len / (OV_BLOCKSIZE * 8) + OV_BEFOREBITF;
     tonextblock = hdr_pagesize - (base & (hdr_pagesize - 1));
@@ -382,13 +381,13 @@ ovparse_part_line(char *l)
     if (S_ISREG(sb.st_mode)
         && (len != sb.st_size || ovbuff->base > sb.st_size)) {
         if (len != sb.st_size)
-            notice("buffindexed: length mismatch '%lu' for index '%d' (%lu "
-                   "bytes)",
+            notice("buffindexed: length mismatch '%lu' for index '%u'"
+                   " (%lu bytes)",
                    (unsigned long) len, ovbuff->index,
                    (unsigned long) sb.st_size);
         if (ovbuff->base > sb.st_size)
-            notice("buffindexed: length must be at least '%lu' for index '%d' "
-                   "(%lu bytes)",
+            notice("buffindexed: length must be at least '%lu' for index '%u'"
+                   " (%lu bytes)",
                    (unsigned long) ovbuff->base, ovbuff->index,
                    (unsigned long) sb.st_size);
         free(ovbuff);
@@ -694,7 +693,7 @@ ovbuffinit_disks(void)
             buf[OVBUFFLASIZ] = '\0';
             i = hex2offt(buf);
             if (i != ovbuff->index) {
-                warn("buffindexed: Mismatch: index '%d' for buffindexed %s", i,
+                warn("buffindexed: Mismatch: index '%u' for buffindexed %s", i,
                      ovbuff->path);
                 ovlock(ovbuff, INN_LOCK_UNLOCK);
                 return false;
@@ -763,8 +762,9 @@ ovbuffinit_disks(void)
             ovbuff->usedblk = 0;
             ovbuff->freeblk = 0;
             ovbuff->updated = 0;
+            /* Force a flush. */
             ovbuff->dirty = OVBUFF_SYNC_COUNT + 1;
-            notice("buffindexed: no magic cookie found for ovbuff %d, "
+            notice("buffindexed: no magic cookie found for ovbuff %u, "
                    "initializing",
                    ovbuff->index);
             ovflushhead(ovbuff);
@@ -956,7 +956,7 @@ retry:
 
 #ifndef OV_DEBUG
     if (ovusedblock(ovbuff, ovbuff->freeblk, false, true)) {
-        notice("buffindexed: fixing invalid free block(%d, %d).",
+        notice("buffindexed: fixing invalid free block(%u, %u).",
                ovbuff->index, ovbuff->freeblk);
     } else
         done = true;
@@ -1030,7 +1030,7 @@ ovblockfree(OV ov)
 
 #ifndef OV_DEBUG
     if (!ovusedblock(ovbuff, ov.blocknum, false, false)) {
-        notice("buffindexed: trying to free block(%d, %d), but already freed.",
+        notice("buffindexed: trying to free block(%d, %u), but already freed.",
                ov.index, ov.blocknum);
     }
 #endif
@@ -1439,8 +1439,8 @@ ovsetcurindexblock(GROUPENTRY *ge)
         return false;
     }
     if ((ovbuff = getovbuff(ov)) == NULL) {
-        warn("buffindexed: ovsetcurindexblock could not get ovbuff block for "
-             "new, %d, %d",
+        warn("buffindexed: ovsetcurindexblock could not get ovbuff block for"
+             " new, %d, %u",
              ov.index, ov.blocknum);
         return false;
     }
@@ -1450,10 +1450,9 @@ ovsetcurindexblock(GROUPENTRY *ge)
     if (PWRITE(ovbuff->fd, &ovindexhead, sizeof(OVINDEXHEAD),
                ovbuff->base + OV_OFFSET(ov.blocknum))
         != sizeof(OVINDEXHEAD)) {
-        syswarn(
-            "buffindexed: could not write index record index '%d', blocknum"
-            " '%d'",
-            ge->curindex.index, ge->curindex.blocknum);
+        syswarn("buffindexed: could not write index record index '%d',"
+                " blocknum '%u'",
+                ge->curindex.index, ge->curindex.blocknum);
         return true;
     }
     if (ge->baseindex.index == NULLINDEX) {
@@ -1462,7 +1461,7 @@ ovsetcurindexblock(GROUPENTRY *ge)
         if ((ovbuff = getovbuff(ge->curindex)) == NULL)
             return false;
         if (!ovusedblock(ovbuff, ge->curindex.blocknum, false, false)) {
-            warn("buffindexed: block(%d, %d) not occupied (index)",
+            warn("buffindexed: block(%u, %u) not occupied (index)",
                  ovbuff->index, ge->curindex.blocknum);
 #ifdef OV_DEBUG
             abort();
@@ -1477,9 +1476,8 @@ ovsetcurindexblock(GROUPENTRY *ge)
         if (PWRITE(ovbuff->fd, &ovindexhead, sizeof(OVINDEXHEAD),
                    ovbuff->base + OV_OFFSET(ge->curindex.blocknum))
             != sizeof(OVINDEXHEAD)) {
-            syswarn("buffindexed: could not write index record index '%d', "
-                    "blocknum"
-                    " '%d'",
+            syswarn("buffindexed: could not write index record index '%d',"
+                    " blocknum '%u'",
                     ge->curindex.index, ge->curindex.blocknum);
             return false;
         }
@@ -1526,8 +1524,8 @@ ovaddrec(GROUPENTRY *ge, ARTNUM artnum, TOKEN token, char *data, int len,
             return false;
         }
         if ((ovbuff = getovbuff(ov)) == NULL) {
-            warn("buffindexed: ovaddrec could not get ovbuff block for new, "
-                 "%d, %d, %ld",
+            warn("buffindexed: ovaddrec could not get ovbuff block for"
+                 " new, %d, %u, %lu",
                  ov.index, ov.blocknum, artnum);
             return false;
         }
@@ -1548,7 +1546,7 @@ ovaddrec(GROUPENTRY *ge, ARTNUM artnum, TOKEN token, char *data, int len,
         }
         if ((ovbuff = getovbuff(ov)) == NULL) {
             warn("buffindexed: ovaddrec could not get ovbuff block for new, "
-                 "%d, %d, %ld",
+                 "%d, %u, %lu",
                  ov.index, ov.blocknum, artnum);
             return false;
         }
@@ -1556,7 +1554,7 @@ ovaddrec(GROUPENTRY *ge, ARTNUM artnum, TOKEN token, char *data, int len,
         ge->curoffset = 0;
     }
     if (!ovusedblock(ovbuff, ge->curdata.blocknum, false, false)) {
-        warn("buffindexed: block(%d, %d) not occupied", ovbuff->index,
+        warn("buffindexed: block(%u, %u) not occupied", ovbuff->index,
              ge->curdata.blocknum);
 #ifdef OV_DEBUG
         buffindexed_close();
@@ -1571,7 +1569,7 @@ ovaddrec(GROUPENTRY *ge, ARTNUM artnum, TOKEN token, char *data, int len,
                ovbuff->base + OV_OFFSET(ge->curdata.blocknum) + ge->curoffset)
         != len) {
         syswarn("buffindexed: could not append overview record index '%d',"
-                " blocknum '%d'",
+                " blocknum '%u'",
                 ge->curdata.index, ge->curdata.blocknum);
         return false;
     }
@@ -1598,7 +1596,7 @@ ovaddrec(GROUPENTRY *ge, ARTNUM artnum, TOKEN token, char *data, int len,
     if ((ovbuff = getovbuff(ge->curindex)) == NULL)
         return false;
     if (!ovusedblock(ovbuff, ge->curindex.blocknum, false, false)) {
-        warn("buffindexed: block(%d, %d) not occupied (index)", ovbuff->index,
+        warn("buffindexed: block(%u, %u) not occupied (index)", ovbuff->index,
              ge->curindex.blocknum);
 #ifdef OV_DEBUG
         buffindexed_close();
@@ -1614,7 +1612,7 @@ ovaddrec(GROUPENTRY *ge, ARTNUM artnum, TOKEN token, char *data, int len,
         != sizeof(ie)) {
         syswarn(
             "buffindexed: could not write index record index '%d', blocknum"
-            " '%d'",
+            " '%u'",
             ge->curindex.index, ge->curindex.blocknum);
         return true;
     }
@@ -1634,8 +1632,7 @@ ovaddrec(GROUPENTRY *ge, ARTNUM artnum, TOKEN token, char *data, int len,
                    ovbuff->base + OV_OFFSET(ge->curindex.blocknum))
             != sizeof(OVINDEXHEAD)) {
             syswarn("buffindexed: could not write index record index '%d', "
-                    "blocknum"
-                    " '%d'",
+                    "blocknum '%u'",
                     ge->curindex.index, ge->curindex.blocknum);
             return true;
         }
@@ -1813,7 +1810,7 @@ ovgroupmmap(GROUPENTRY *ge, ARTNUM low, ARTNUM high, bool needov)
         ovbuff = getovbuff(ov);
         if (ovbuff == NULL) {
             warn("buffindexed: ovgroupmmap ovbuff is null(ovindex is %d, "
-                 "ovblock is %d",
+                 "ovblock is %u",
                  ov.index, ov.blocknum);
             ovgroupunmap();
             return false;
@@ -1891,8 +1888,8 @@ ovgroupmmap(GROUPENTRY *ge, ARTNUM low, ARTNUM high, bool needov)
             ov = gdb->datablk;
             ovbuff = getovbuff(ov);
             if (ovbuff == NULL) {
-                warn("buffindexed: ovgroupmmap could not get ovbuff block for "
-                     "new, %d, %d",
+                warn("buffindexed: ovgroupmmap could not get ovbuff block for"
+                     " new, %d, %u",
                      ov.index, ov.blocknum);
                 free(gdb);
                 ovgroupunmap();
@@ -2042,8 +2039,8 @@ ovsearch(void *handle, ARTNUM *artnum, char **data, int *len, TOKEN *token,
                         search->gdb.datablk.index = srchov.index;
                         ovbuff = getovbuff(srchov);
                         if (ovbuff == NULL) {
-                            warn("buffindexed: ovsearch could not get ovbuff "
-                                 "block for new, %d, %d",
+                            warn("buffindexed: ovsearch could not get ovbuff"
+                                 " block for new, %d, %u",
                                  srchov.index, srchov.blocknum);
                             return false;
                         }
@@ -2311,7 +2308,10 @@ buffindexed_expiregroup(const char *group, int *lo, struct history *h)
     GROUPlock(gloc, INN_LOCK_WRITE);
     ge = &GROUPentries[gloc.recno];
     if (ge->count == 0) {
-        ge->low = ge->high + 1;
+        ge->low = ge->low > ge->high ? ge->low : ge->high;
+        if (ge->low == 0)
+            ge->low = 1;
+        ge->high = ge->low - 1;
         if (lo != NULL)
             *lo = ge->low;
         ge->expired = time(NULL);
@@ -2381,9 +2381,12 @@ buffindexed_expiregroup(const char *group, int *lo, struct history *h)
         newge.low = newge.high;
     }
     if (newge.count == 0) {
-        /* The low water mark should be one more than the high water mark
-         * when there is no article in the group. */
-        newge.low = newge.high + 1;
+        /* The high water mark should be one less than the low water mark when
+         * there is no article in the group. */
+        newge.low = newge.low > newge.high ? newge.low : newge.high;
+        if (newge.low == 0)
+            newge.low = 1;
+        newge.high = newge.low - 1;
     }
     *ge = newge;
     if (lo != NULL) {
@@ -2494,10 +2497,10 @@ buffindexed_close(void)
                             break;
                         }
                     }
-                    fprintf(F, "%d: % 6ld, % 2d: 0x%08x, % 10ld, % 10ld\n",
+                    fprintf(F, "%d: % 6ld, % 2d: 0x%08x, % 10lu, % 10lu\n",
                             ovbuff->index, i, j, trace->ov_trace[j].gloc.recno,
-                            trace->ov_trace[j].occupied,
-                            trace->ov_trace[j].freed);
+                            (unsigned long) trace->ov_trace[j].occupied,
+                            (unsigned long) trace->ov_trace[j].freed);
                 }
             }
         }
@@ -2604,13 +2607,14 @@ main(int argc, char **argv)
         exit(1);
     }
     fprintf(stdout, "GROUPheader->freelist.recno is %d(0x%08x)\n",
-            GROUPheader->freelist.recno, GROUPheader->freelist.recno);
+            GROUPheader->freelist.recno,
+            (unsigned int) GROUPheader->freelist.recno);
     group = argv[1];
     if (isdigit((unsigned char) *group)) {
         gloc.recno = atoi(group);
         ge = &GROUPentries[gloc.recno];
-        fprintf(stdout, "left articles are %d for %d, last expiry is %ld\n",
-                ge->count, gloc.recno, (long) ge->expired);
+        fprintf(stdout, "left articles are %d for %d, last expiry is %lu\n",
+                ge->count, gloc.recno, (unsigned long) ge->expired);
         if (ge->count == 0) {
             GROUPlock(gloc, INN_LOCK_UNLOCK);
             exit(0);
@@ -2625,7 +2629,7 @@ main(int argc, char **argv)
         fprintf(stdout, "%d index block(s)\n", i);
         fprintf(stdout, "%d data block(s)\n", countgdb());
         for (giblist = Giblist; giblist != NULL; giblist = giblist->next) {
-            fprintf(stdout, "  % 8d(% 5d)\n", giblist->ov.blocknum,
+            fprintf(stdout, "  % 8d(% 5d)\n", (int) giblist->ov.blocknum,
                     giblist->ov.index);
         }
         for (i = 0; i < Gibcount; i++) {
@@ -2649,7 +2653,7 @@ main(int argc, char **argv)
     }
     GROUPlock(gloc, INN_LOCK_READ);
     ge = &GROUPentries[gloc.recno];
-    fprintf(stdout, "base %d(%d), cur %d(%d), expired at %s\n",
+    fprintf(stdout, "base %u(%d), cur %u(%d), expired at %s\n",
             ge->baseindex.blocknum, ge->baseindex.index, ge->curindex.blocknum,
             ge->curindex.index,
             ge->expired == 0 ? "none\n" : ctime(&ge->expired));
@@ -2666,14 +2670,14 @@ main(int argc, char **argv)
         exit(1);
     }
     fprintf(stdout, "  gloc is %d(0x%08x)\n", search->gloc.recno,
-            search->gloc.recno);
+            (unsigned int) search->gloc.recno);
     for (giblist = Giblist, i = 0; giblist != NULL;
          giblist = giblist->next, i++)
         ;
     fprintf(stdout, "%d index block(s)\n", i);
     fprintf(stdout, "%d data block(s)\n", countgdb());
     for (giblist = Giblist; giblist != NULL; giblist = giblist->next) {
-        fprintf(stdout, "  % 8d(% 5d)\n", giblist->ov.blocknum,
+        fprintf(stdout, "  % 8d(% 5d)\n", (int) giblist->ov.blocknum,
                 giblist->ov.index);
     }
     for (i = 0; i < Gibcount; i++) {
